Grant Jenks Tools
=================

`Grant Jenks`_ tools.

.. _`Grant Jenks`: http://www.grantjenks.com


Features
--------

- Pure-Python
- Developed on Python 2.7
- Tested on CPython 2.7

Quickstart
----------

Installing ``gj`` is simple with `pip <https://pip.pypa.io/en/stable/>`_::

  $ pip install gj

You can access documentation in the interpreter with Python's built-in help
function::

  >>> import gj
  >>> help(gj)

Reference and Indices
---------------------

.. toctree::

   api

* `GJ at PyPI`_
* `GJ at GitHub`_
* `GJ Issue Tracker`_
* :ref:`search`
* :ref:`genindex`

.. _`GJ at PyPI`: https://pypi.python.org/pypi/gj/
.. _`GJ at GitHub`: https://github.com/grantjenks/python-gj/
.. _`GJ Issue Tracker`: https://github.com/grantjenks/python-gj/issues/

License
-------

.. include:: ../LICENSE
